This is a wrapper function that tries to determint the type of WHO VA
instrument used to collect the data. If the input (i.e., the odk export)
includes a column containing the string "ID1A110" (or "id1a110"), then this
function assumes the data were collected using the 2014 WHO VA instrument.
If the input (i.e., the odk export) contains the string "age_neonate_hours"
and does not contain the string "ID1A110" (or "id1a110"), then the function
assumes the questionnaire version is 1.4.1 from the 2016 instrument. If
neither condition is met, then the function assumes the data were collected
with version 1.5.1 of the 2016 WHO VA instrument. Note: versions 1.5.2 and
1.5.2 do not include changes that require modification for the data preparation,
so the code for version 1.5.1 should also work for these later two versions.
By default, this function assumes the data column named 'meta.instanceID'
contains the unique ID for each record. If this column is not found, then
the ID is set to 1:nrow(odk). Alternatively, the user may specify the
column name containing the ID by passing a string to the id_col parameter.